searchData={"content_type":"text/markdown","items":[{"doc":"A toolkit for working with ISO 639-1 language codes.\n\nISO6391 offers functionality to:\n- Convert a language name into its respective ISO 639-1 code.\n- Fetch the language name(s) corresponding to a particular ISO 639-1 code.\n\nISO 639-1 codes serve as standardized two-letter abbreviations for languages.","ref":"ISO6391.html","title":"ISO6391","type":"module"},{"doc":"iex> ISO6391.to_code(\"French\")\n    \"fr\"\n\n    iex> ISO6391.from_code(\"fr\")\n    \"French\"","ref":"ISO6391.html#module-examples","title":"Examples - ISO6391","type":"module"},{"doc":"Retrieves language name(s) mapped to a particular ISO 639-1 code.\n\nReturns a language name or names corresponding to the provided `code`, or `nil` if no match is found.","ref":"ISO6391.html#from_code/1","title":"ISO6391.from_code/1","type":"function"},{"doc":"- `code`: A binary representing the ISO 639-1 code.","ref":"ISO6391.html#from_code/1-parameters","title":"Parameters - ISO6391.from_code/1","type":"function"},{"doc":"iex> ISO6391.from_code(\"pt\")\n    \"Portuguese\"\n\n    iex> ISO6391.from_code(\"undefined_code\")\n    nil","ref":"ISO6391.html#from_code/1-examples","title":"Examples - ISO6391.from_code/1","type":"function"},{"doc":"Some ISO 639-1 codes may map to multiple language names.\nIn such instances, this function delivers a string, concatenating all correlated language names, separated by commas.","ref":"ISO6391.html#from_code/1-notes","title":"Notes - ISO6391.from_code/1","type":"function"},{"doc":"Translates a language name into the corresponding ISO 639-1 code.\n\nReturns the associated ISO 639-1 code for a supplied `language_name` if available, or `nil` otherwise.","ref":"ISO6391.html#to_code/1","title":"ISO6391.to_code/1","type":"function"},{"doc":"- `language_name`: A binary representing the language name.","ref":"ISO6391.html#to_code/1-parameters","title":"Parameters - ISO6391.to_code/1","type":"function"},{"doc":"iex> ISO6391.to_code(\"Spanish\")\n    \"es\"\n\n    iex> ISO6391.to_code(\"UnrecognizedLanguage\")\n    nil","ref":"ISO6391.html#to_code/1-examples","title":"Examples - ISO6391.to_code/1","type":"function"},{"doc":"# ISO_639_1_ex\r\n\r\nISO_639_1_ex is a simple Elixir library for converting between ISO 639-1 codes and language names.","ref":"readme.html","title":"ISO_639_1_ex","type":"extras"},{"doc":"Add `iso_639_1_ex` to your list of dependencies in `mix.exs`:\r\n\r\n```elixir\r\ndef deps do\r\n  [\r\n    {:iso_639_1_ex, \"~> 0.1.0\"}\r\n  ]\r\nend\r\n```","ref":"readme.html#installation","title":"Installation - ISO_639_1_ex","type":"extras"},{"doc":"```elixir\r\n# Get the ISO 639-1 code for English\r\nISO6391.to_code(\"English\")\r\n#=> \"en\"\r\n\r\n# Get the language name for the ISO 639-1 code \"en\"\r\nISO6391.from_code(\"en\")\r\n#=> \"English\"\r\n```\r\n\r\n#","ref":"readme.html#usage","title":"Usage - ISO_639_1_ex","type":"extras"},{"doc":"The docs can be found at [HexDocs](https://hexdocs.pm/iso_629_1_ex/readme.html).","ref":"readme.html#documentation","title":"Documentation - ISO_639_1_ex","type":"extras"},{"doc":"# Changelog\r\n \n\n## [Unreleased] - ReleaseDate\r\n\r\n## [0.1.1] - 2023-10-16\r\n#","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"* Library mix name\r\n\r\n## [0.1.0] - 2023-10-13\r\n#","ref":"changelog.html#fixed","title":"Fixed - Changelog","type":"extras"},{"doc":"* Initial library configuration\r\n* List of all language codes\r\n* Function to convert from ISO_639_1 code to language name\r\n* Function to convert from language name code to ISO_639_1\r\n\r\n \n[Unreleased]: https://github.com/wois-org/ISO_639_1_ex/v0.1.1...HEAD\r\n[0.1.1]: https://github.com/wois-org/ISO_639_1_ex/v0.1.0...v0.1.1\r\n[0.1.0]: https://github.com/wois-org/ISO_639_1_ex/compare/4718b80...v0.1.0","ref":"changelog.html#added","title":"Added - Changelog","type":"extras"},{"doc":"MIT License\n\nCopyright (c) 2023 Wois\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html","title":"LICENSE","type":"extras"}]}